
// The View holds all the objects that will be seen
// The View may be guided by the Model and gets passed to the Controller
// Anything the Controller will need to control store on v (this)

export class View {

    constructor(m) {

        // receive m for the model
        // and store the view (this) on v just for convenience
        const v = this;

        // optional styling of various components
        STYLE = {        
            Stepper:{
                vertical:true,
                stepperType:"number",
                scale:.8
            },
            Label:{color:light}        
        }

        // Each page for each orientation gets made
        // This repeats things like the logo, but often is easier to manage
        // you are welcome to keep one logo and do not swipe the logo from page to page
        // We think swiping the logo from page to page looks more natural
        // Make sure to clone() images that are on more than one page

        // ~~~~~~~~~~~~~~  PAGE 1 HORIZONTAL  ~~~~~~~~~~~

        // Store any pages that gets referenced to in Controller on v (the View)
        // any parts of the page (logo, steppers, etc.) can then be stored as a property of the page
        let page1 = v.pageH1 = new Container(W, H);
        page1.type = "Region";

        let header = new Container().addTo(page1);
        page1.logo = new Pic("logo.png").expand().addTo(header);
        new Label("MVC - Model View Controller").loc(14, page1.logo.height + 20, header);

        let content = new Container(700, 700).addTo(page1);
        let tile = new Tile([
            page1.stepper1 = new Stepper(),
            page1.stepper2 = new Stepper(),
            page1.stepper3 = new Stepper()
        ], 3, 1, 30, 30, true).center(content);
        // set the steppers to the data from m (the Model)
        tile.loop((stepper,i)=>{
            stepper.currentValue = m.data[0][i];
        });

        let footer = new Container().addTo(page1);
        page1.icon = new Pic("icon.jpg").addTo(footer);

        // Create a Layout for the page 
        // holder, regions, lastMargin, lastMarginMin, backgroundColor, vertical, showRegions, scalingObject
        new Layout(page1, [
            {object:header, marginLeft:2, maxHeight:80},
            {object:content, marginLeft:2, valign:"center", backgroundColor:yellow, width:60},
            {object:footer, marginLeft:2, maxHeight:90, width:10, valign:"bottom"},
        ], 2, null, null, false, null, S);


        // ~~~~~~~~~~~~~~  PAGE 2 HORIZONTAL  ~~~~~~~~~~~

        let page2 = v.pageH2 = new Container(W, H);

        header = new Container().addTo(page2);
        page2.logo = new Pic("logo.png").expand().addTo(header);
        new Label("MVC - Model View Controller").loc(14, page1.logo.height + 20, header)

        content = new Container(400, 400).addTo(page2);
        let list = page2.list = new List().center(content);
        list.selectedIndex = m.data[1];

        footer = new Container().addTo(page2);
        page2.icon = new Pic("icon.jpg").addTo(footer);

        new Layout(page2, [
            {object:header, marginLeft:2, maxHeight:80},
            {object:content, marginLeft:2, valign:"center", backgroundColor:green, width:60},
            {object:footer, marginLeft:2, maxHeight:90, valign:"bottom"},
        ], 2, null, null, false, null, S);

        // ~~~~~~~~~~~~~~  PAGES HORIZONTAL ~~~~~~~~~~~

        // Create a Pages object 
       v.pagesH = new Pages([
            {page:page1, swipe:[page2, page2]},
            {page:page2, swipe:[page1, page1]}
        ], "slide");


        // ~~~~~~~~~~~~~~  PAGE 1 VERTICAL  ~~~~~~~~~~~

        page1 = v.pageV1 = new Container(W, H);

        header = new Container().addTo(page1);
        page1.logo = new Pic("logo.png").expand().addTo(header);
        new Label("MVC - Model View Controller").loc(14, page1.logo.height + 20, header)

        content = new Container(700, 700).addTo(page1);
        tile = new Tile([
            page1.stepper1 = new Stepper(),
            page1.stepper2 = new Stepper(),
            page1.stepper3 = new Stepper()
        ], 3, 1, 30, 30, true).center(content);
        tile.loop((stepper,i)=>{
            stepper.currentValue = m.data[0][i];
        });

        footer = new Container().addTo(page1);
        page1.icon = new Pic("icon.jpg").addTo(footer);

        new Layout(page1, [
            {object:header, marginTop:2, maxHeight:80},
            {object:content, marginTop:2, valign:"center", backgroundColor:yellow, height:60},
            {object:footer, marginTop:2, maxHeight:90, height:10, valign:"bottom"},
        ], 2, null, null, true, null, S);

        // ~~~~~~~~~~~~~~  PAGE 2 VERTICAL  ~~~~~~~~~~~

        page2 = v.pageV2 = new Container(W, H);

        header = new Container().addTo(page2);
        page2.logo = new Pic("logo.png").expand().addTo(header);
        new Label("MVC - Model View Controller").loc(14, page1.logo.height + 20, header)

        content = new Container(400, 400).addTo(page2);
        list = page2.list = new List().center(content);
        list.selectedIndex = m.data[1];

        footer = new Container().addTo(page2);
        page2.icon = new Pic("icon.jpg").addTo(footer);

        new Layout(page2, [
            {object:header, marginTop:2, maxHeight:80},
            {object:content, marginTop:2, valign:"center", backgroundColor:green, height:60},
            {object:footer, marginTop:2, maxHeight:90, height:10, valign:"bottom"},
        ], 2, null, null, true, null, S); 

        // ~~~~~~~~~~~~~~  PAGES VERTICAL ~~~~~~~~~~~

        v.pagesV = new Pages([
            {page:page1, swipe:[null, null, page2, page2]},
            {page:page2, swipe:[null, null, page1, page1]}
        ], "slide");
    }

} // end of View class

